@@ -4,8 +4,8 @@
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
 //-----------------------------------------------------------------------------
-var BUGNUMBER = 457065;
-var summary = 'Do not assert: !fp->callee || fp->thisp == fp->argv[-1].toObjectOrNull()';
+var BUGNUMBER = 452498;
+var summary = 'TM: upvar2 regression tests';
 var actual = '';
 var expect = '';
 
@@ -20,11 +20,19 @@ function test()
   printBugNumber(BUGNUMBER);
   printStatus (summary);
 
+// ------- Comment #92 From Jesse Ruderman
 
-  var e = eval;
-  for (var a in this) { }
-  (function() { eval("this; for (let b in [0,1,2]) { }"); })();
-
+  expect = 'SyntaxError: redeclaration of formal parameter e';
+  try
+  {
+    eval('(function (e) { var e; const e = undefined; });');
+  }
+  catch(ex)
+  {
+    actual = ex + '';
+  }
+// Without patch: "SyntaxError: redeclaration of var e"
+// expected new behavior // With patch:    "SyntaxError: redeclaration of formal parameter e:"
 
   reportCompare(expect, actual, summary);
 
