@@ -493,8 +493,9 @@ MimeHeaders_get_parameter (const char *header_value, const char *parm_name,
   if (NS_FAILED(rv))
     return nullptr;
 
+  nsCString hdr_value(header_value);
   nsCString result;
-  rv = mimehdrpar->GetParameterInternal(header_value, parm_name, charset,
+  rv = mimehdrpar->GetParameterInternal(hdr_value, parm_name, charset,
                                         language, getter_Copies(result));
   return NS_SUCCEEDED(rv) ? PL_strdup(result.get()) : nullptr;
 }
