@@ -1,5 +1,4 @@
 /* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
-/* vim:set et cin ts=4 sw=4 sts=4: */
 /* This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
@@ -453,7 +452,8 @@ private:
 
     void SetPushedStream(Http2PushedStreamWrapper *stream);
 
-    void SetDoNotTrack();
+    void SetOriginHeader();
+    void SetGPC();
 
 private:
     nsCOMPtr<nsICancelable>           mProxyRequest;
